<?php
namespace Teknisa\COZ\Services;

class Pla07000Service{

	protected $environment;
    protected $util;
    protected $pla07000remoteRepository;

	public function __construct($environment, $util, $pla07000remoteRepository){
        $this->environment = $environment;
        $this->util = $util;
        $this->pla07000remoteRepository = $pla07000remoteRepository;
    }

    public function preencheCampos(&$row) {
        if($row['CDGRUPFILI'] == '') {
            $row['CDGRUPFILI'] = 'T';
        }
    	$row['LISTAGRUPFILI'] = $row['CDGRUPFILI'];
        $row['LISTAFILIAGREGA'] = $this->retornaFiliaisagregadas((array)$row);
        $row['LISTAGRUPSERV'] = $this->retornaGrupserv((array)$row);

        $row['SERVICOFILIAL'] = $this->retornaServicoporfiliais((array)$row);
        $row['LISTASERVFILI'] = $this->concatArray($row['SERVICOFILIAL'], 'SERVICO');
    }

    public function retornaFiliaisagregadas($row) {
    	if($row['T_NMFILIAGREGA'] === 'S') {   
            $row['CDGRUPFILI'] = $row['LISTAGRUPFILI'];

            //valores que o filtro de filiais agregadar precisa
            $fieldsToFilter = array("NRORG", "CDGRUPFILI", "CDCENTRAL");

            $paramObjectArray = $this->buildFilterArrayFromRow($row, $fieldsToFilter);

            $row['NMFILIAGREGA'] = $this->pla07000remoteRepository->fetchFiliaisagregadas($paramObjectArray);
        }
        return $this->concatArray($row['NMFILIAGREGA']);
    }

    public function retornaGrupserv($row) {
    	if($row['T_NMGRUPSERV'] === 'S') {   
            $row['NMGRUPSERV'] = $this->pla07000remoteRepository->fetchGrupserv();
        }
        return $this->concatArray($row['NMGRUPSERV']);
    }

    public function retornaServicoporfiliais($row) {
    	if($row['T_NMSERVFILI'] === 'S') {
            $row['CDGRUPFILI'] = $row['LISTAGRUPFILI'];
            $row['CDGRUPSERV'] = $row['LISTAGRUPSERV'];
            $row['CDFILIAGREGA'] = $row['LISTAFILIAGREGA'];

            //valores que o filtro de serviços precisa
            $fieldsToFilter = array("NRORG", "CDGRUPFILI", "CDCENTRAL", "CDGRUPSERV", "CDFILIAGREGA");

            $paramObjectArray = $this->buildFilterArrayFromRow($row, $fieldsToFilter);

            $row['SERVICOFILIAL'] = $this->pla07000remoteRepository->fetchServicos($paramObjectArray);
        }
        return $row['SERVICOFILIAL'];
    }

	public function concatArray($array, $key = false) {
        if ($key) {
            $string = '';
            foreach ($array as $item) {
              $string .= $item[$key].'_';
            }
            return trim($string, '_');
        }
        else return implode($array, "_");
    }

    /*
     * Constroi um array de arrays a partir de uma row, no formato chave=>valor,
     * e um array de strings especificando quais das colunas deverão ser usadas
     */
    public function buildFilterArrayFromRow($row, $filterKeys) {
 
        //pega todos os valores de $row com chaves presentes em $filterKeys
        //o array_flip faz com que os valores de $filterKeys sejam chaves
        $paramValueArray = array_intersect_key($row, array_flip($filterKeys));

        return array_map(function($key, $value) {
            return array("columnName"=>$key, "operator"=>"=", "value"=>$value); 
        }, array_keys($paramValueArray), $paramValueArray);
    }
}